km3pipe\.hardware\.Detector
===========================

.. currentmodule:: km3pipe.hardware

.. autoclass:: Detector

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Detector.__init__
      ~Detector.domid2floor
      ~Detector.get_pmt
      ~Detector.pmt_with_id
      ~Detector.pmtid2omkey
      ~Detector.translate_detector
      ~Detector.write
   
   

   
   
   